@@ -100,12 +100,16 @@ impl<'a,S> Report<'a,S> for PreprocessedReport<'a,S>
         match self.warnings.load(Ordering::SeqCst) {
             0 => { /* no warnings was emmitted, good ! */ },
             1 => {
-                Diagnostic::warning().with_message("1 warning emitted").emit(self)
+                Diagnostic::warning().with_message("1 warning emitted").emit(self);
+                // but this warning should not be counted
+                self.warnings.fetch_sub(1, Ordering::SeqCst);
             },
             n => {
                 Diagnostic::warning()
                     .with_message(format!("{} warnings emitted", n))
                     .emit(self);
+                // but this warning should not be counted
+                self.warnings.fetch_sub(1, Ordering::SeqCst);
             }
         }
         match self.errors.load(Ordering::SeqCst) {
@@ -115,12 +119,16 @@ impl<'a,S> Report<'a,S> for PreprocessedReport<'a,S>
             },
             1 => {
                 Diagnostic::error().with_message("1 error emitted").emit(self);
+                // but this error should not be counted
+                self.errors.fetch_sub(1, Ordering::SeqCst);
                 Err(())
             },
             n => {
                 Diagnostic::error()
                     .with_message(format!("{} errors emitted", n))
                     .emit(self);
+                // but this error should not be counted
+                self.errors.fetch_sub(1, Ordering::SeqCst);
                 Err(())
             }
         }
